==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/kubernetes/api/model/ISCSIVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class ISCSIVolumeSourceBuilder extends ISCSIVolumeSourceFluentImpl<ISCSIVolumeSourceBuilder> implements VisitableBuilder<ISCSIVolumeSource,ISCSIVolumeSourceBuilder>{

    ISCSIVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public ISCSIVolumeSourceBuilder(){
            this(true);
    }
    public ISCSIVolumeSourceBuilder(Boolean validationEnabled){
            this(new ISCSIVolumeSource(), validationEnabled);
    }
    public ISCSIVolumeSourceBuilder(ISCSIVolumeSourceFluent<?> fluent){
            this(fluent, true);
    }
    public ISCSIVolumeSourceBuilder(ISCSIVolumeSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ISCSIVolumeSource(), validationEnabled);
    }
    public ISCSIVolumeSourceBuilder(ISCSIVolumeSourceFluent<?> fluent,ISCSIVolumeSource instance){
            this(fluent, instance, true);
    }
    public ISCSIVolumeSourceBuilder(ISCSIVolumeSourceFluent<?> fluent,ISCSIVolumeSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withFsType(instance.getFsType()); 
            fluent.withIqn(instance.getIqn()); 
            fluent.withIscsiInterface(instance.getIscsiInterface()); 
            fluent.withLun(instance.getLun()); 
            fluent.withReadOnly(instance.getReadOnly()); 
            fluent.withTargetPortal(instance.getTargetPortal()); 
            this.validationEnabled = validationEnabled; 
    }
    public ISCSIVolumeSourceBuilder(ISCSIVolumeSource instance){
            this(instance,true);
    }
    public ISCSIVolumeSourceBuilder(ISCSIVolumeSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withFsType(instance.getFsType()); 
            this.withIqn(instance.getIqn()); 
            this.withIscsiInterface(instance.getIscsiInterface()); 
            this.withLun(instance.getLun()); 
            this.withReadOnly(instance.getReadOnly()); 
            this.withTargetPortal(instance.getTargetPortal()); 
            this.validationEnabled = validationEnabled; 
    }

    public ISCSIVolumeSource build(){
            ISCSIVolumeSource buildable = new ISCSIVolumeSource(fluent.getFsType(),fluent.getIqn(),fluent.getIscsiInterface(),fluent.getLun(),fluent.isReadOnly(),fluent.getTargetPortal());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ISCSIVolumeSourceBuilder that = (ISCSIVolumeSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.74-sources.jar: annotations/io/fabric8/kubernetes/api/model/ISCSIVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ISCSIVolumeSourceBuilder extends ISCSIVolumeSourceFluentImpl<ISCSIVolumeSourceBuilder> implements VisitableBuilder<ISCSIVolumeSource,ISCSIVolumeSourceBuilder>{

    ISCSIVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public ISCSIVolumeSourceBuilder(){
            this(true);
    }
    public ISCSIVolumeSourceBuilder(Boolean validationEnabled){
            this(new ISCSIVolumeSource(), validationEnabled);
    }
    public ISCSIVolumeSourceBuilder(ISCSIVolumeSourceFluent<?> fluent){
            this(fluent, true);
    }
    public ISCSIVolumeSourceBuilder(ISCSIVolumeSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ISCSIVolumeSource(), validationEnabled);
    }
    public ISCSIVolumeSourceBuilder(ISCSIVolumeSourceFluent<?> fluent,ISCSIVolumeSource instance){
            this(fluent, instance, true);
    }
    public ISCSIVolumeSourceBuilder(ISCSIVolumeSourceFluent<?> fluent,ISCSIVolumeSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withFsType(instance.getFsType()); 
            fluent.withIqn(instance.getIqn()); 
            fluent.withIscsiInterface(instance.getIscsiInterface()); 
            fluent.withLun(instance.getLun()); 
            fluent.withReadOnly(instance.getReadOnly()); 
            fluent.withTargetPortal(instance.getTargetPortal()); 
            this.validationEnabled = validationEnabled; 
    }
    public ISCSIVolumeSourceBuilder(ISCSIVolumeSource instance){
            this(instance,true);
    }
    public ISCSIVolumeSourceBuilder(ISCSIVolumeSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withFsType(instance.getFsType()); 
            this.withIqn(instance.getIqn()); 
            this.withIscsiInterface(instance.getIscsiInterface()); 
            this.withLun(instance.getLun()); 
            this.withReadOnly(instance.getReadOnly()); 
            this.withTargetPortal(instance.getTargetPortal()); 
            this.validationEnabled = validationEnabled; 
    }

    public ISCSIVolumeSource build(){
            ISCSIVolumeSource buildable = new ISCSIVolumeSource(fluent.getFsType(),fluent.getIqn(),fluent.getIscsiInterface(),fluent.getLun(),fluent.isReadOnly(),fluent.getTargetPortal());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ISCSIVolumeSourceBuilder that = (ISCSIVolumeSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
